/**
 *  CSE 154
 *  Lab 8 Regex and Form Validation
 *  Exercise 2: Epizzeria
 *  Part III: Validation in PHP
 *  (Starter JS)
 *
 *  This starter JS provides the code to send a POST request to epizzeria.php,
 *  and logs the response JSON in the console. See epizzeria.php comments for more
 *  information!
 */
(function() {
  "use strict";
  const URL = "epizzeria.php";

  window.addEventListener("load", initialize);
  
  function initialize() {
    // prevent the default form behavior when a submit button is clicked - we want to 
    // post through an ajax request instead
    $("order-form").addEventListener("submit", function(event) {
      event.preventDefault(); // submit action on forms by default redirect page, so prevent that behavior
      // if we've gotten in here, all html5 validation checks have passed
      validateFormInputs();
    });
  }

  function validateOrder() {
    let params = new FormData();
    // Recall that we can pass in a <form> DOM element as a parameter to the
    // FormData constructor - all input elements in this form which have a name
    // attribute will be sent in the POST request. The key will be the name, and value
    // will be the selected/inputted value for that input element.

    fetch(URL, { method: "POST", body : params })
      .then(checkStatus)
      .then(JSON.parse)
      .then(displayOrderResults)
      .catch(displayRequestError);
  }

  function displayOrderResults(responseData) {
    console.log(responseData); // This starter code logs the POST array sent/returned from epizzeria.php!
    // TODO: Display useful response message based on successful order results!
  }

  function displayRequestError(responseData) {
    console.log(responseData); // remove after testing
    // TOOD: Provide useful error messages based on your returned response from epizzeria.php!
  }

  // ------------------------- Helper Functions ------------------------- // 
  /**
   * Helper function to return the response's result text if successful, otherwise
   * returns the rejected Promise result with an error status and corresponding text
   * @param {object} response - response to check for success/error
   * @return {object} - valid result text if response was successful, otherwise rejected
   *                    Promise result
   */
  function checkStatus(response) {
    if (response.status >= 200 && response.status < 300 || response.status == 0) {
      return response.text();
    } else { 
      return Promise.reject(new Error(response.status + ": " + response.statusText));
    }
  }

  /**
   * Returns the element that has the ID attribute with the specified value.
   * @param {string} id - element ID.
   * @return {object} DOM object associated with id.
   */
  function $(id) {
    return document.getElementById(id);
  }

  /**
   * Returns an array of DOM elements matching given query selector (alias for
   * document.querySelectorAll) 
   * @param {string} query - query matching returned DOM elements.
   * @return {object[]} array of DOM objects matching the given query.
   */
  function qsa(query) {
    return document.querySelectorAll(query);
  }

  /*
   * Returns the first DOM element that matches the given query (alias for
   * document.querySelector) 
   * @param {string} query - query matching returned DOM element.
   * @return {object} first DOM object matching the given query.
   */
  function qs(query) {
    return document.querySelector(query);
  }
})();
